==> mobroute-0.5.0.tar.gz: mobroute-v0.5.0/dbstubquery_test/loadstoptoparent_test.go <==
package dbstubquery_test

import (
	"os"
	"reflect"
	"testing"

	"git.sr.ht/~mil/mobroute/dbstubquery"
	"git.sr.ht/~mil/mobroute/dbt"
	"git.sr.ht/~mil/mobroute/testhelper/dbquerytesthelper"
)

func Test_LoadStopToParent(t *testing.T) {
	testCases := []struct {
		Test                string
		MockGTFS            map[int]string
		Source              uint
		ExpectStopToParents []dbt.StopToParent
	}{
		{
			Test:     "Properly translates location_type={null,1,2,3,4} to ultimate parent station",
			MockGTFS: map[int]string{42: "../testhelper/mockgtfs/gtfs_simple_stops.yml"},
			Source:   42,
			ExpectStopToParents: []dbt.StopToParent{
				// Source, StopID, ParentStation
				{42, "station_a", "station_a"},
				{42, "station_b", "station_b"},
				{42, "entrance", "station_b"},
				{42, "node", "station_a"},
				{42, "blankplatform_no_parent", "blankplatform_no_parent"},
				{42, "blankplatform_w_parent", "station_a"},
				{42, "platform_no_parent", "platform_no_parent"},
				{42, "platform_w_parent", "station_a"},
				{42, "boardarea_a", "station_a"},
				{42, "boardarea_b", "platform_no_parent"},
			},
		},
	}

	for _, testCase := range testCases {
		if sqlxDB, dbPath, err := dbquerytesthelper.PrepareMockLoadComputeAndOpenDB(
			testCase.MockGTFS,
		); err != nil {
			t.Fatalf("Error preparing testcase: %v", err)
		} else if stoptoparents, err := dbstubquery.LoadStopToParent(
			sqlxDB, testCase.Source,
		); err != nil {
			t.Fatalf("Error: %v: DB: %s", err, dbPath)
		} else if !reflect.DeepEqual(testCase.ExpectStopToParents, *stoptoparents) {
			t.Fatalf(
				"LoadStopParent Test failed: %s - expected: %v; got: %v; DB: (%s)",
				testCase.Test, testCase.ExpectStopToParents, *stoptoparents, dbPath,
			)
		} else {
			os.Remove(dbPath)
		}
	}
}

==> mobroute-0.7.0.tar.gz: mobroute-v0.7.0/dbstubquery_test/loadstoptoparent_test.go <==
package dbstubquery_test

import (
	"os"
	"reflect"
	"testing"

	"git.sr.ht/~mil/mobroute/dbstubquery"
	"git.sr.ht/~mil/mobroute/dbt"
	"git.sr.ht/~mil/mobroute/testhelper/dbquerytesthelper"
)

func Test_LoadStopToParent(t *testing.T) {
	testCases := []struct {
		Test                string
		MockGTFS            map[int]string
		FeedID              uint
		ExpectStopToParents []dbt.StopToParent
	}{
		{
			Test:     "Properly translates location_type={null,1,2,3,4} to ultimate parent station",
			MockGTFS: map[int]string{42: "../testhelper/mockgtfs/gtfs_simple_stops.yml"},
			FeedID:   42,
			ExpectStopToParents: []dbt.StopToParent{
				// FeedID, StopID, ParentStation
				{42, "station_a", "station_a"},
				{42, "station_b", "station_b"},
				{42, "entrance", "station_b"},
				{42, "node", "station_a"},
				{42, "blankplatform_no_parent", "blankplatform_no_parent"},
				{42, "blankplatform_w_parent", "station_a"},
				{42, "platform_no_parent", "platform_no_parent"},
				{42, "platform_w_parent", "station_a"},
				{42, "boardarea_a", "station_a"},
				{42, "boardarea_b", "platform_no_parent"},
			},
		},
	}

	for _, testCase := range testCases {
		if sqlxDB, dbPath, err := dbquerytesthelper.PrepareMockLoadComputeAndOpenDB(
			testCase.MockGTFS,
		); err != nil {
			t.Fatalf("Error preparing testcase: %v", err)
		} else if stoptoparents, err := dbstubquery.LoadStopToParent(
			sqlxDB, testCase.FeedID,
		); err != nil {
			t.Fatalf("Error: %v: DB: %s", err, dbPath)
		} else if !reflect.DeepEqual(testCase.ExpectStopToParents, *stoptoparents) {
			t.Fatalf(
				"LoadStopParent Test failed: %s - expected: %v; got: %v; DB: (%s)",
				testCase.Test, testCase.ExpectStopToParents, *stoptoparents, dbPath,
			)
		} else {
			os.Remove(dbPath)
		}
	}
}
